context("canvasXpress Web Charts - Boxplot")


test_that("cXboxplot1", {
    check_ui_test(cXboxplot1())
})

test_that("cXboxplot2", {
    check_ui_test(cXboxplot2())
})

test_that("cXboxplot3", {
    check_ui_test(cXboxplot3())
})

test_that("cXboxplot4", {
    check_ui_test(cXboxplot4())
})

test_that("cXboxplot5", {
    check_ui_test(cXboxplot5())
})

test_that("cXboxplot6", {
    check_ui_test(cXboxplot6())
})

test_that("cXboxplot7", {
    check_ui_test(cXboxplot7())
})

test_that("cXboxplot8", {
    check_ui_test(cXboxplot8())
})

test_that("cXboxplot9", {
    check_ui_test(cXboxplot9())
})

test_that("cXboxplot10", {
    check_ui_test(cXboxplot10())
})

test_that("cXboxplot11", {
    check_ui_test(cXboxplot11())
})

test_that("cXboxplot12", {
    check_ui_test(cXboxplot12())
})

test_that("cXboxplot13", {
    check_ui_test(cXboxplot13())
})

test_that("cXboxplot14", {
    check_ui_test(cXboxplot14())
})

test_that("cXboxplot15", {
    check_ui_test(cXboxplot15())
})

test_that("cXboxplot16", {
    check_ui_test(cXboxplot16())
})

test_that("cXboxplot17", {
    check_ui_test(cXboxplot17())

    warning('Data points appearing on the chart are too small, unless it is resized manually or refreshed')
})

test_that("cXboxplot18", {
    check_ui_test(cXboxplot18())

    warning('Data points appearing on the chart are too small, unless it is resized manually or refreshed')
})

test_that("cXboxplot19", {
    check_ui_test(cXboxplot19())
})
